@@ -649,6 +649,8 @@ class Formatter(Configurable):
         self._current_page = page
         page.output_attrs['html']['scripts'] = OrderedSet()
         page.output_attrs['html']['stylesheets'] = OrderedSet()
+        page.output_attrs['html']['dark-stylesheets'] = OrderedSet()
+        page.output_attrs['html']['light-stylesheets'] = OrderedSet()
         page.output_attrs['html']['extra_html'] = []
         page.output_attrs['html']['edit_button'] = ''
         page.output_attrs['html']['extra_footer_html'] = []
@@ -728,18 +730,29 @@ class Formatter(Configurable):
 
         scripts.extend(page.output_attrs['html']['scripts'])
         stylesheets.extend(page.output_attrs['html']['stylesheets'])
+        dark_stylesheets = page.output_attrs['html']['dark-stylesheets']
+        light_stylesheets = page.output_attrs['html']['light-stylesheets']
+
         scripts_basenames = [os.path.basename(script)
                              for script in scripts]
         stylesheets_basenames = [os.path.basename(stylesheet)
                                  for stylesheet in stylesheets]
+        dark_stylesheets_basenames = [os.path.basename(stylesheet)
+                                 for stylesheet in dark_stylesheets]
+        light_stylesheets_basenames = [os.path.basename(stylesheet)
+                                 for stylesheet in light_stylesheets]
 
         Formatter.all_stylesheets.update(stylesheets)
+        Formatter.all_stylesheets.update(dark_stylesheets)
+        Formatter.all_stylesheets.update(light_stylesheets)
         Formatter.all_scripts.update(scripts)
 
         out = template.render(
             {'page': page,
              'scripts': scripts_basenames,
              'stylesheets': stylesheets_basenames,
+             'dark_stylesheets': dark_stylesheets_basenames,
+             'light_stylesheets': light_stylesheets_basenames,
              'rel_path': rel_path,
              'attrs': page.output_attrs['html'],
              'meta': {},
@@ -1055,7 +1068,26 @@ class Formatter(Configurable):
         try:
             os.makedirs(os.path.join(themepath))
             with tarfile.open(tarball) as file_:
-                file_.extractall(themepath)
+                def is_within_directory(directory, target):
+                    
+                    abs_directory = os.path.abspath(directory)
+                    abs_target = os.path.abspath(target)
+                
+                    prefix = os.path.commonprefix([abs_directory, abs_target])
+                    
+                    return prefix == abs_directory
+                
+                def safe_extract(tar, path=".", members=None, *, numeric_owner=False):
+                
+                    for member in tar.getmembers():
+                        member_path = os.path.join(path, member.name)
+                        if not is_within_directory(path, member_path):
+                            raise Exception("Attempted Path Traversal in Tar File")
+                
+                    tar.extractall(path, members, numeric_owner=numeric_owner) 
+                    
+                
+                safe_extract(file_, themepath)
         except tarfile.ReadError:
             warn('download-theme-error',
                  "%s is not a supported tarball - Using default theme" %
@@ -1106,6 +1138,8 @@ class Formatter(Configurable):
             Formatter.engine = Engine(
                 loader=FileLoader(searchpath, encoding='UTF-8'),
                 extensions=[CoreExtension(), CodeExtension()])
+            # https://github.com/akornatskyy/wheezy.template/issues/68#issuecomment-1441529466
+            Formatter.engine.compiler.source_lineno = 0
             Formatter.engine.global_vars.update({'e': html.escape})
 
             Formatter.initialized = True
